#[non_exhaustive]#[repr(i32)]pub enum AccelerationStructureBuildType {
Host = 0,
Device = 1,
HostOrDevice = 2,
}Expand description
Where the building of an acceleration structure will take place.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Host = 0
Building will take place on the host.
Device = 1
Building will take place on the device.
HostOrDevice = 2
Building will take place on either the host or the device.