pub struct AccelerationStructureCreateFlags(/* private fields */);Expand description
Flags that control how an acceleration structure is created.
Implementations
Sourceimpl AccelerationStructureCreateFlags
impl AccelerationStructureCreateFlags
Sourcepub const fn empty() -> AccelerationStructureCreateFlags
pub const fn empty() -> AccelerationStructureCreateFlags
Returns a AccelerationStructureCreateFlags with none of the flags set.
Sourcepub const fn none() -> AccelerationStructureCreateFlags
👎Deprecated since 0.31.0: use empty instead
pub const fn none() -> AccelerationStructureCreateFlags
empty insteadReturns a AccelerationStructureCreateFlags with none of the flags set.
Sourcepub const fn intersects(self, other: AccelerationStructureCreateFlags) -> bool
pub const fn intersects(self, other: AccelerationStructureCreateFlags) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: AccelerationStructureCreateFlags) -> bool
pub const fn contains(self, other: AccelerationStructureCreateFlags) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn union(
self,
other: AccelerationStructureCreateFlags,
) -> AccelerationStructureCreateFlags
pub const fn union( self, other: AccelerationStructureCreateFlags, ) -> AccelerationStructureCreateFlags
Returns the union of self and other.
Sourcepub const fn intersection(
self,
other: AccelerationStructureCreateFlags,
) -> AccelerationStructureCreateFlags
pub const fn intersection( self, other: AccelerationStructureCreateFlags, ) -> AccelerationStructureCreateFlags
Returns the intersection of self and other.
Sourcepub const fn difference(
self,
other: AccelerationStructureCreateFlags,
) -> AccelerationStructureCreateFlags
pub const fn difference( self, other: AccelerationStructureCreateFlags, ) -> AccelerationStructureCreateFlags
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(
self,
other: AccelerationStructureCreateFlags,
) -> AccelerationStructureCreateFlags
pub const fn symmetric_difference( self, other: AccelerationStructureCreateFlags, ) -> AccelerationStructureCreateFlags
Returns the flags that are set in self or other, but not in both.