pub enum BufferMemory {
Normal(ResourceMemory),
Sparse,
}Expand description
The type of backing memory that a buffer can have.
Variants
Normal(ResourceMemory)
The buffer is backed by normal memory, bound with bind_memory.
Sparse
The buffer is backed by sparse memory, bound with bind_sparse.