CommandBufferAlloc

Trait CommandBufferAlloc 

pub unsafe trait CommandBufferAlloc:
    DeviceOwned
    + Send
    + Sync
    + 'static {
    // Required methods
    fn inner(&self) -> &CommandPoolAlloc;
    fn queue_family_index(&self) -> u32;
}
A command buffer allocated from a pool that has finished being recorded.

Safety

See CommandBufferAllocator for information about safety.

Required Methods

fn inner(&self) -> &CommandPoolAlloc

Returns the internal object that contains the command buffer.

fn queue_family_index(&self) -> u32

Returns the index of the queue family that the pool targets.

Implementors