#[repr(i32)]pub enum CommandBufferLevel {
Primary = 0,
Secondary = 1,
}Expand description
Determines the kind of command buffer to create.
Variants
Primary = 0
Primary command buffers can be executed on a queue, and can call secondary command buffers. Render passes must begin and end within the same primary command buffer.
Secondary = 1
Secondary command buffers cannot be executed on a queue, but can be executed by a primary command buffer. If created for a render pass, they must fit within a single render subpass.