pub struct CommandPoolCreateFlags(/* private fields */);Expand description
Additional properties of the command pool.
Implementations
Sourceimpl CommandPoolCreateFlags
impl CommandPoolCreateFlags
Sourcepub const TRANSIENT: CommandPoolCreateFlags
pub const TRANSIENT: CommandPoolCreateFlags
A hint to the implementation that the command buffers allocated from this pool will be short-lived.
Sourcepub const RESET_COMMAND_BUFFER: CommandPoolCreateFlags
pub const RESET_COMMAND_BUFFER: CommandPoolCreateFlags
Command buffers allocated from this pool can be reset individually.
Sourcepub const fn empty() -> CommandPoolCreateFlags
pub const fn empty() -> CommandPoolCreateFlags
Returns a CommandPoolCreateFlags with none of the flags set.
Sourcepub const fn none() -> CommandPoolCreateFlags
👎Deprecated since 0.31.0: use empty instead
pub const fn none() -> CommandPoolCreateFlags
empty insteadReturns a CommandPoolCreateFlags with none of the flags set.
Sourcepub const fn intersects(self, other: CommandPoolCreateFlags) -> bool
pub const fn intersects(self, other: CommandPoolCreateFlags) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: CommandPoolCreateFlags) -> bool
pub const fn contains(self, other: CommandPoolCreateFlags) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn union(
self,
other: CommandPoolCreateFlags,
) -> CommandPoolCreateFlags
pub const fn union( self, other: CommandPoolCreateFlags, ) -> CommandPoolCreateFlags
Returns the union of self and other.
Sourcepub const fn intersection(
self,
other: CommandPoolCreateFlags,
) -> CommandPoolCreateFlags
pub const fn intersection( self, other: CommandPoolCreateFlags, ) -> CommandPoolCreateFlags
Returns the intersection of self and other.
Sourcepub const fn difference(
self,
other: CommandPoolCreateFlags,
) -> CommandPoolCreateFlags
pub const fn difference( self, other: CommandPoolCreateFlags, ) -> CommandPoolCreateFlags
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(
self,
other: CommandPoolCreateFlags,
) -> CommandPoolCreateFlags
pub const fn symmetric_difference( self, other: CommandPoolCreateFlags, ) -> CommandPoolCreateFlags
Returns the flags that are set in self or other, but not in both.