pub struct CommandPoolCreateInfo {
pub flags: CommandPoolCreateFlags,
pub queue_family_index: u32,
pub _ne: NonExhaustive,
}Expand description
Parameters to create an CommandPool.
Fields
flags: CommandPoolCreateFlagsAdditional properties of the command pool.
The default value is empty.
queue_family_index: u32The index of the queue family that this pool is created for. All command buffers allocated from this pool must be submitted on a queue belonging to that family.
The default value is u32::MAX, which must be overridden.
_ne: NonExhaustiveTrait Implementations
Sourceimpl Clone for CommandPoolCreateInfo
impl Clone for CommandPoolCreateInfo
Sourcefn clone(&self) -> CommandPoolCreateInfo
fn clone(&self) -> CommandPoolCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandPoolCreateInfo
impl Debug for CommandPoolCreateInfo
Sourceimpl Default for CommandPoolCreateInfo
impl Default for CommandPoolCreateInfo
Sourcefn default() -> CommandPoolCreateInfo
fn default() -> CommandPoolCreateInfo
Returns the “default value” for a type. Read more