pub struct CommandPoolResetFlags(/* private fields */);Expand description
Additional properties of the command pool reset operation.
Implementations
Sourceimpl CommandPoolResetFlags
impl CommandPoolResetFlags
Sourcepub const RELEASE_RESOURCES: CommandPoolResetFlags
pub const RELEASE_RESOURCES: CommandPoolResetFlags
A hint to the implementation that it should free all the memory internally allocated for this pool.
Sourcepub const fn empty() -> CommandPoolResetFlags
pub const fn empty() -> CommandPoolResetFlags
Returns a CommandPoolResetFlags with none of the flags set.
Sourcepub const fn none() -> CommandPoolResetFlags
👎Deprecated since 0.31.0: use empty instead
pub const fn none() -> CommandPoolResetFlags
empty insteadReturns a CommandPoolResetFlags with none of the flags set.
Sourcepub const fn intersects(self, other: CommandPoolResetFlags) -> bool
pub const fn intersects(self, other: CommandPoolResetFlags) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: CommandPoolResetFlags) -> bool
pub const fn contains(self, other: CommandPoolResetFlags) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn union(self, other: CommandPoolResetFlags) -> CommandPoolResetFlags
pub const fn union(self, other: CommandPoolResetFlags) -> CommandPoolResetFlags
Returns the union of self and other.
Sourcepub const fn intersection(
self,
other: CommandPoolResetFlags,
) -> CommandPoolResetFlags
pub const fn intersection( self, other: CommandPoolResetFlags, ) -> CommandPoolResetFlags
Returns the intersection of self and other.
Sourcepub const fn difference(
self,
other: CommandPoolResetFlags,
) -> CommandPoolResetFlags
pub const fn difference( self, other: CommandPoolResetFlags, ) -> CommandPoolResetFlags
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(
self,
other: CommandPoolResetFlags,
) -> CommandPoolResetFlags
pub const fn symmetric_difference( self, other: CommandPoolResetFlags, ) -> CommandPoolResetFlags
Returns the flags that are set in self or other, but not in both.