pub struct CommandBufferInheritanceInfo {
pub render_pass: Option<CommandBufferInheritanceRenderPassType>,
pub occlusion_query: Option<QueryControlFlags>,
pub query_statistics_flags: QueryPipelineStatisticFlags,
pub _ne: NonExhaustive,
}Expand description
The context that a secondary command buffer can inherit from the primary command buffer it’s executed in.
Fields
render_pass: Option<CommandBufferInheritanceRenderPassType>If Some, the secondary command buffer is required to be executed within a render pass
instance, and can only call draw operations.
If None, it must be executed outside a render pass instance, and can execute dispatch and
transfer operations, but not drawing operations.
The default value is None.
occlusion_query: Option<QueryControlFlags>If Some, the secondary command buffer is allowed to be executed within a primary that has
an occlusion query active. The inner QueryControlFlags specifies which flags the
active occlusion is allowed to have enabled.
If None, the primary command buffer cannot have an occlusion query active when this
secondary command buffer is executed.
The inherited_queries feature must be enabled if this is Some.
The default value is None.
query_statistics_flags: QueryPipelineStatisticFlagsWhich pipeline statistics queries are allowed to be active on the primary command buffer when this secondary command buffer is executed.
If this value is not empty, the pipeline_statistics_query feature must be enabled on
the device.
The default value is QueryPipelineStatisticFlags::empty().
_ne: NonExhaustiveTrait Implementations
Sourceimpl Clone for CommandBufferInheritanceInfo
impl Clone for CommandBufferInheritanceInfo
Sourcefn clone(&self) -> CommandBufferInheritanceInfo
fn clone(&self) -> CommandBufferInheritanceInfo
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more