pub struct CommandBufferInheritanceRenderPassInfo {
pub subpass: Subpass,
pub framebuffer: Option<Arc<Framebuffer>>,
}Expand description
The render pass context that a secondary command buffer is created for.
Fields
subpass: SubpassThe render subpass that this secondary command buffer must be executed within.
There is no default value.
framebuffer: Option<Arc<Framebuffer>>The framebuffer object that will be used when calling the command buffer. This parameter is optional and is an optimization hint for the implementation.
The default value is None.
Implementations
Sourceimpl CommandBufferInheritanceRenderPassInfo
impl CommandBufferInheritanceRenderPassInfo
Sourcepub fn subpass(subpass: Subpass) -> CommandBufferInheritanceRenderPassInfo
pub fn subpass(subpass: Subpass) -> CommandBufferInheritanceRenderPassInfo
Returns a CommandBufferInheritanceRenderPassInfo with the specified subpass.