pub struct ImageCopy {
pub src_subresource: ImageSubresourceLayers,
pub src_offset: [u32; 3],
pub dst_subresource: ImageSubresourceLayers,
pub dst_offset: [u32; 3],
pub extent: [u32; 3],
pub _ne: NonExhaustive,
}Expand description
A region of data to copy between images.
Fields
src_subresource: ImageSubresourceLayersThe subresource of src_image to copy from.
The default value is empty, which must be overridden.
src_offset: [u32; 3]The offset from the zero coordinate of src_image that copying will start from.
The default value is [0; 3].
dst_subresource: ImageSubresourceLayersThe subresource of dst_image to copy to.
The default value is empty, which must be overridden.
dst_offset: [u32; 3]The offset from the zero coordinate of dst_image that copying will start from.
The default value is [0; 3].
extent: [u32; 3]The extent of texels to copy.
The default value is [0; 3], which must be overridden.
_ne: NonExhaustiveTrait Implementations