pub struct SubpassBeginInfo {
pub contents: SubpassContents,
pub _ne: NonExhaustive,
}Expand description
Parameters to begin a new subpass within a render pass.
Fields
contents: SubpassContentsWhat kinds of commands will be recorded in the subpass.
The default value is SubpassContents::Inline.
_ne: NonExhaustiveTrait Implementations
Sourceimpl Clone for SubpassBeginInfo
impl Clone for SubpassBeginInfo
Sourcefn clone(&self) -> SubpassBeginInfo
fn clone(&self) -> SubpassBeginInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubpassBeginInfo
impl Debug for SubpassBeginInfo
Sourceimpl Default for SubpassBeginInfo
impl Default for SubpassBeginInfo
Sourcefn default() -> SubpassBeginInfo
fn default() -> SubpassBeginInfo
Returns the “default value” for a type. Read more