pub struct DescriptorSetLayoutCreateFlags(/* private fields */);Expand description
Flags that control how a descriptor set layout is created.
Implementations
Sourceimpl DescriptorSetLayoutCreateFlags
impl DescriptorSetLayoutCreateFlags
Sourcepub const UPDATE_AFTER_BIND_POOL: DescriptorSetLayoutCreateFlags
pub const UPDATE_AFTER_BIND_POOL: DescriptorSetLayoutCreateFlags
Whether descriptor sets using this descriptor set layout must be allocated from a
descriptor pool whose flags contain DescriptorPoolCreateFlags::UPDATE_AFTER_BIND.
Descriptor set layouts with this flag use alternative (typically higher) device limits on
per-stage and total descriptor counts, which have _update_after_bind_ in their names.
This flag must be specified whenever the layout contains one or more bindings that have
the DescriptorBindingFlags::UPDATE_AFTER_BIND flag, but can be specified also if none
of the bindings have this flag, purely to use the alternative device limits.
Sourcepub const PUSH_DESCRIPTOR: DescriptorSetLayoutCreateFlags
pub const PUSH_DESCRIPTOR: DescriptorSetLayoutCreateFlags
Whether the descriptor set layout should be created for push descriptors.
If set, the layout can only be used for push descriptors, and if not set, it can only be used for regular descriptor sets.
If set, there are several restrictions:
- There must be no bindings with a type of
DescriptorType::UniformBufferDynamic,DescriptorType::StorageBufferDynamicorDescriptorType::InlineUniformBlock. - There must be no bindings with
variable_descriptor_countenabled. - The total number of descriptors across all bindings must be less than the
max_push_descriptorslimit.
Sourcepub const fn empty() -> DescriptorSetLayoutCreateFlags
pub const fn empty() -> DescriptorSetLayoutCreateFlags
Returns a DescriptorSetLayoutCreateFlags with none of the flags set.
Sourcepub const fn none() -> DescriptorSetLayoutCreateFlags
👎Deprecated since 0.31.0: use empty instead
pub const fn none() -> DescriptorSetLayoutCreateFlags
empty insteadReturns a DescriptorSetLayoutCreateFlags with none of the flags set.
Sourcepub const fn intersects(self, other: DescriptorSetLayoutCreateFlags) -> bool
pub const fn intersects(self, other: DescriptorSetLayoutCreateFlags) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: DescriptorSetLayoutCreateFlags) -> bool
pub const fn contains(self, other: DescriptorSetLayoutCreateFlags) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn union(
self,
other: DescriptorSetLayoutCreateFlags,
) -> DescriptorSetLayoutCreateFlags
pub const fn union( self, other: DescriptorSetLayoutCreateFlags, ) -> DescriptorSetLayoutCreateFlags
Returns the union of self and other.
Sourcepub const fn intersection(
self,
other: DescriptorSetLayoutCreateFlags,
) -> DescriptorSetLayoutCreateFlags
pub const fn intersection( self, other: DescriptorSetLayoutCreateFlags, ) -> DescriptorSetLayoutCreateFlags
Returns the intersection of self and other.
Sourcepub const fn difference(
self,
other: DescriptorSetLayoutCreateFlags,
) -> DescriptorSetLayoutCreateFlags
pub const fn difference( self, other: DescriptorSetLayoutCreateFlags, ) -> DescriptorSetLayoutCreateFlags
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(
self,
other: DescriptorSetLayoutCreateFlags,
) -> DescriptorSetLayoutCreateFlags
pub const fn symmetric_difference( self, other: DescriptorSetLayoutCreateFlags, ) -> DescriptorSetLayoutCreateFlags
Returns the flags that are set in self or other, but not in both.