pub struct DescriptorSetLayoutCreateInfo {
pub flags: DescriptorSetLayoutCreateFlags,
pub bindings: BTreeMap<u32, DescriptorSetLayoutBinding>,
pub _ne: NonExhaustive,
}Expand description
Parameters to create a new DescriptorSetLayout.
Fields
flags: DescriptorSetLayoutCreateFlagsSpecifies how to create the descriptor set layout.
bindings: BTreeMap<u32, DescriptorSetLayoutBinding>The bindings of the desriptor set layout. These are specified according to binding number.
It is generally advisable to keep the binding numbers low. Higher binding numbers may use more memory inside Vulkan.
The default value is empty.
_ne: NonExhaustiveTrait Implementations
Sourceimpl Clone for DescriptorSetLayoutCreateInfo
impl Clone for DescriptorSetLayoutCreateInfo
Sourcefn clone(&self) -> DescriptorSetLayoutCreateInfo
fn clone(&self) -> DescriptorSetLayoutCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for DescriptorSetLayoutCreateInfo
impl Default for DescriptorSetLayoutCreateInfo
Sourcefn default() -> DescriptorSetLayoutCreateInfo
fn default() -> DescriptorSetLayoutCreateInfo
Returns the “default value” for a type. Read more