PersistentDescriptorSet

Struct PersistentDescriptorSet 

pub struct PersistentDescriptorSet<P = StandardDescriptorSetAlloc> { /* private fields */ }
A simple, immutable descriptor set that is expected to be long-lived.

Implementations

Source

impl PersistentDescriptorSet

pub fn new<A>( allocator: &A, layout: Arc<DescriptorSetLayout>, descriptor_writes: impl IntoIterator<Item = WriteDescriptorSet>, descriptor_copies: impl IntoIterator<Item = CopyDescriptorSet>, ) -> Result<Arc<PersistentDescriptorSet<<A as DescriptorSetAllocator>::Alloc>>, Validated<VulkanError>>

Creates and returns a new descriptor set with a variable descriptor count of 0.

See new_with_pool for more.

pub fn new_variable<A>( allocator: &A, layout: Arc<DescriptorSetLayout>, variable_descriptor_count: u32, descriptor_writes: impl IntoIterator<Item = WriteDescriptorSet>, descriptor_copies: impl IntoIterator<Item = CopyDescriptorSet>, ) -> Result<Arc<PersistentDescriptorSet<<A as DescriptorSetAllocator>::Alloc>>, Validated<VulkanError>>

Creates and returns a new descriptor set with the requested variable descriptor count, allocating it from the provided pool.

Panics
  • Panics if layout was created for push descriptors rather than descriptor sets.
  • Panics if variable_descriptor_count is too large for the given layout.