pub struct QueueCreateFlags(/* private fields */);Expand description
Flags specifying additional properties of a queue.
Implementations
Sourceimpl QueueCreateFlags
impl QueueCreateFlags
pub const PROTECTED: QueueCreateFlags
Sourcepub const fn empty() -> QueueCreateFlags
pub const fn empty() -> QueueCreateFlags
Returns a QueueCreateFlags with none of the flags set.
Sourcepub const fn none() -> QueueCreateFlags
👎Deprecated since 0.31.0: use empty instead
pub const fn none() -> QueueCreateFlags
empty insteadReturns a QueueCreateFlags with none of the flags set.
Sourcepub const fn intersects(self, other: QueueCreateFlags) -> bool
pub const fn intersects(self, other: QueueCreateFlags) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: QueueCreateFlags) -> bool
pub const fn contains(self, other: QueueCreateFlags) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn union(self, other: QueueCreateFlags) -> QueueCreateFlags
pub const fn union(self, other: QueueCreateFlags) -> QueueCreateFlags
Returns the union of self and other.
Sourcepub const fn intersection(self, other: QueueCreateFlags) -> QueueCreateFlags
pub const fn intersection(self, other: QueueCreateFlags) -> QueueCreateFlags
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: QueueCreateFlags) -> QueueCreateFlags
pub const fn difference(self, other: QueueCreateFlags) -> QueueCreateFlags
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(
self,
other: QueueCreateFlags,
) -> QueueCreateFlags
pub const fn symmetric_difference( self, other: QueueCreateFlags, ) -> QueueCreateFlags
Returns the flags that are set in self or other, but not in both.