pub struct QueueCreateInfo {
pub flags: QueueCreateFlags,
pub queue_family_index: u32,
pub queues: Vec<f32>,
pub _ne: NonExhaustive,
}Expand description
Parameters to create queues in a new Device.
Fields
flags: QueueCreateFlagsAdditional properties of the queue.
The default value is empty.
queue_family_index: u32The index of the queue family to create queues for.
The default value is 0.
queues: Vec<f32>The queues to create for the given queue family, each with a relative priority.
The relative priority value is an arbitrary number between 0.0 and 1.0. Giving a queue a higher priority is a hint to the driver that the queue should be given more processing time. As this is only a hint, different drivers may handle this value differently and there are no guarantees about its behavior.
The default value is a single queue with a priority of 0.5.
_ne: NonExhaustiveTrait Implementations
Sourceimpl Clone for QueueCreateInfo
impl Clone for QueueCreateInfo
Sourcefn clone(&self) -> QueueCreateInfo
fn clone(&self) -> QueueCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueueCreateInfo
impl Debug for QueueCreateInfo
Sourceimpl Default for QueueCreateInfo
impl Default for QueueCreateInfo
Sourcefn default() -> QueueCreateInfo
fn default() -> QueueCreateInfo
Returns the “default value” for a type. Read more