FormatFeatures

Struct FormatFeatures 

pub struct FormatFeatures(/* private fields */);
The features supported by a device for an image or buffer with a particular format.

Implementations

Source

impl FormatFeatures

pub const SAMPLED_IMAGE: FormatFeatures

Can be used with a sampled image descriptor.

pub const STORAGE_IMAGE: FormatFeatures

Can be used with a storage image descriptor.

pub const STORAGE_IMAGE_ATOMIC: FormatFeatures

Can be used with a storage image descriptor with atomic operations in a shader.

pub const STORAGE_READ_WITHOUT_FORMAT: FormatFeatures

Can be used with a storage image descriptor for reading, without specifying a format on the image view.

pub const STORAGE_WRITE_WITHOUT_FORMAT: FormatFeatures

Can be used with a storage image descriptor for writing, without specifying a format on the image view.

pub const COLOR_ATTACHMENT: FormatFeatures

Can be used with a color attachment in a framebuffer, or with an input attachment descriptor.

pub const COLOR_ATTACHMENT_BLEND: FormatFeatures

Can be used with a color attachment in a framebuffer with blending, or with an input attachment descriptor.

pub const DEPTH_STENCIL_ATTACHMENT: FormatFeatures

Can be used with a depth/stencil attachment in a framebuffer, or with an input attachment descriptor.

pub const FRAGMENT_DENSITY_MAP: FormatFeatures

Can be used with a fragment density map attachment in a framebuffer.

pub const FRAGMENT_SHADING_RATE_ATTACHMENT: FormatFeatures

Can be used with a fragment shading rate attachment in a framebuffer.

pub const TRANSFER_SRC: FormatFeatures

Can be used with the source image in a transfer (copy) operation.

pub const TRANSFER_DST: FormatFeatures

Can be used with the destination image in a transfer (copy) operation.

pub const BLIT_SRC: FormatFeatures

Can be used with the source image in a blit operation.

pub const BLIT_DST: FormatFeatures

Can be used with the destination image in a blit operation.

pub const SAMPLED_IMAGE_FILTER_LINEAR: FormatFeatures

Can be used with samplers or as a blit source, using the Linear filter.

pub const SAMPLED_IMAGE_FILTER_CUBIC: FormatFeatures

Can be used with samplers or as a blit source, using the Cubic filter.

pub const SAMPLED_IMAGE_FILTER_MINMAX: FormatFeatures

Can be used with samplers using a reduction mode of Min or Max.

pub const MIDPOINT_CHROMA_SAMPLES: FormatFeatures

Can be used with sampler YCbCr conversions using a chroma offset of Midpoint.

pub const COSITED_CHROMA_SAMPLES: FormatFeatures

Can be used with sampler YCbCr conversions using a chroma offset of CositedEven.

pub const SAMPLED_IMAGE_YCBCR_CONVERSION_LINEAR_FILTER: FormatFeatures

Can be used with sampler YCbCr conversions using the Linear chroma filter.

pub const SAMPLED_IMAGE_YCBCR_CONVERSION_SEPARATE_RECONSTRUCTION_FILTER: FormatFeatures

Can be used with sampler YCbCr conversions whose chroma filter differs from the filters of the base sampler.

pub const SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT: FormatFeatures

When used with a sampler YCbCr conversion, the implementation will always perform explicit chroma reconstruction.

pub const SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_FORCEABLE: FormatFeatures

Can be used with sampler YCbCr conversions with forced explicit reconstruction.

pub const SAMPLED_IMAGE_DEPTH_COMPARISON: FormatFeatures

Can be used with samplers using depth comparison.

pub const VIDEO_DECODE_OUTPUT: FormatFeatures

Can be used with the output image of a video decode operation.

pub const VIDEO_DECODE_DPB: FormatFeatures

Can be used with the DPB image of a video decode operation.

pub const VIDEO_ENCODE_INPUT: FormatFeatures

Can be used with the input image of a video encode operation.

pub const VIDEO_ENCODE_DPB: FormatFeatures

Can be used with the DPB image of a video encode operation.

pub const DISJOINT: FormatFeatures

For multi-planar formats, can be used with images created with the DISJOINT flag.

pub const LINEAR_COLOR_ATTACHMENT: FormatFeatures

pub const WEIGHT_IMAGE: FormatFeatures

pub const WEIGHT_SAMPLED_IMAGE: FormatFeatures

pub const BLOCK_MATCHING: FormatFeatures

pub const BOX_FILTER_SAMPLED: FormatFeatures

pub const OPTICAL_FLOW_IMAGE: FormatFeatures

pub const OPTICAL_FLOW_VECTOR: FormatFeatures

pub const OPTICAL_FLOW_COST: FormatFeatures

pub const UNIFORM_TEXEL_BUFFER: FormatFeatures

Can be used with a uniform texel buffer descriptor.

pub const STORAGE_TEXEL_BUFFER: FormatFeatures

Can be used with a storage texel buffer descriptor.

pub const STORAGE_TEXEL_BUFFER_ATOMIC: FormatFeatures

Can be used with a storage texel buffer descriptor with atomic operations in a shader.

pub const VERTEX_BUFFER: FormatFeatures

Can be used as the format of a vertex attribute in the vertex input state of a graphics pipeline.

pub const ACCELERATION_STRUCTURE_VERTEX_BUFFER: FormatFeatures

Can be used as the vertex format when building an acceleration structure.

pub const fn empty() -> FormatFeatures

Returns a FormatFeatures with none of the flags set.

pub const fn none() -> FormatFeatures

👎Deprecated since 0.31.0: use empty instead

Returns a FormatFeatures with none of the flags set.

pub const fn count(self) -> u32

Returns the number of flags set in self.

pub const fn is_empty(self) -> bool

Returns whether no flags are set in self.

pub const fn intersects(self, other: FormatFeatures) -> bool

Returns whether any flags are set in both self and other.

pub const fn contains(self, other: FormatFeatures) -> bool

Returns whether all flags in other are set in self.

pub const fn union(self, other: FormatFeatures) -> FormatFeatures

Returns the union of self and other.

pub const fn intersection(self, other: FormatFeatures) -> FormatFeatures

Returns the intersection of self and other.

pub const fn difference(self, other: FormatFeatures) -> FormatFeatures

Returns self without the flags set in other.

pub const fn symmetric_difference(self, other: FormatFeatures) -> FormatFeatures

Returns the flags that are set in self or other, but not in both.