#[non_exhaustive]#[repr(i32)]pub enum ValidationFeatureEnable {
GpuAssisted = 0,
GpuAssistedReserveBindingSlot = 1,
BestPractices = 2,
DebugPrintf = 3,
SynchronizationValidation = 4,
}Expand description
Features of the validation layer to enable.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
GpuAssisted = 0
The validation layer will use shader programs running on the GPU to provide additional validation.
This must not be used together with DebugPrintf.
GpuAssistedReserveBindingSlot = 1
The validation layer will reserve and use one descriptor set slot for its own use.
The limit reported by
max_bound_descriptor_sets
will be reduced by 1.
GpuAssisted must also be enabled.
BestPractices = 2
The validation layer will report recommendations that are not strictly errors, but that may be considered good Vulkan practice.
DebugPrintf = 3
The validation layer will process debugPrintfEXT operations in shaders, and send them
to the debug callback.
This must not be used together with GpuAssisted.
SynchronizationValidation = 4
The validation layer will report errors relating to synchronization, such as data races and the use of synchronization primitives.