pub struct DebugUtilsLabel {
pub label_name: String,
pub color: [f32; 4],
pub _ne: NonExhaustive,
}Expand description
A label to associate with a span of work in a queue.
When debugging, labels can be useful to identify which queue, or where in a specific queue, something happened.
Fields
label_name: StringThe name of the label.
The default value is empty.
color: [f32; 4]An RGBA color value that is associated with the label, with values in the range 0.0..=1.0.
If set to [0.0; 4], the value is ignored.
The default value is [0.0; 4].
_ne: NonExhaustiveTrait Implementations
Sourceimpl Clone for DebugUtilsLabel
impl Clone for DebugUtilsLabel
Sourcefn clone(&self) -> DebugUtilsLabel
fn clone(&self) -> DebugUtilsLabel
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DebugUtilsLabel
impl Debug for DebugUtilsLabel
Sourceimpl Default for DebugUtilsLabel
impl Default for DebugUtilsLabel
Sourcefn default() -> DebugUtilsLabel
fn default() -> DebugUtilsLabel
Returns the “default value” for a type. Read more