DebugUtilsMessageType

Struct DebugUtilsMessageType 

pub struct DebugUtilsMessageType(/* private fields */);
Type of message.

Implementations

Source

impl DebugUtilsMessageType

pub const GENERAL: DebugUtilsMessageType

Specifies that some general event has occurred.

pub const VALIDATION: DebugUtilsMessageType

Specifies that something has occurred during validation against the vulkan specification

pub const PERFORMANCE: DebugUtilsMessageType

Specifies a potentially non-optimal use of Vulkan

pub const fn empty() -> DebugUtilsMessageType

Returns a DebugUtilsMessageType with none of the flags set.

pub const fn none() -> DebugUtilsMessageType

👎Deprecated since 0.31.0: use empty instead

Returns a DebugUtilsMessageType with none of the flags set.

pub const fn count(self) -> u32

Returns the number of flags set in self.

pub const fn is_empty(self) -> bool

Returns whether no flags are set in self.

pub const fn intersects(self, other: DebugUtilsMessageType) -> bool

Returns whether any flags are set in both self and other.

pub const fn contains(self, other: DebugUtilsMessageType) -> bool

Returns whether all flags in other are set in self.

pub const fn union(self, other: DebugUtilsMessageType) -> DebugUtilsMessageType

Returns the union of self and other.

pub const fn intersection( self, other: DebugUtilsMessageType, ) -> DebugUtilsMessageType

Returns the intersection of self and other.

pub const fn difference( self, other: DebugUtilsMessageType, ) -> DebugUtilsMessageType

Returns self without the flags set in other.

pub const fn symmetric_difference( self, other: DebugUtilsMessageType, ) -> DebugUtilsMessageType

Returns the flags that are set in self or other, but not in both.