DebugUtilsMessengerCreateInfo

Struct DebugUtilsMessengerCreateInfo 

pub struct DebugUtilsMessengerCreateInfo {
    pub message_severity: DebugUtilsMessageSeverity,
    pub message_type: DebugUtilsMessageType,
    pub user_callback: Arc<DebugUtilsMessengerCallback>,
    pub _ne: NonExhaustive,
}
Parameters to create a DebugUtilsMessenger.

Fields

message_severity: DebugUtilsMessageSeverity

The message severity types that the callback should be called for.

The value must not be empty.

The default value is MessageSeverity::errors_and_warnings().

message_type: DebugUtilsMessageType

The message types that the callback should be called for.

The value must not be empty.

The default value is MessageType::general().

user_callback: Arc<DebugUtilsMessengerCallback>

The closure that should be called.

The closure must not make any calls to the Vulkan API. If the closure panics, the panic is caught and ignored.

_ne: NonExhaustive

Implementations

Source

impl DebugUtilsMessengerCreateInfo

pub fn user_callback( user_callback: Arc<DebugUtilsMessengerCallback>, ) -> DebugUtilsMessengerCreateInfo

Returns a DebugUtilsMessengerCreateInfo with the specified user_callback.