pub struct InstanceCreateFlags(/* private fields */);Expand description
Flags specifying additional properties of an instance.
Implementations
Sourceimpl InstanceCreateFlags
impl InstanceCreateFlags
Sourcepub const ENUMERATE_PORTABILITY: InstanceCreateFlags
pub const ENUMERATE_PORTABILITY: InstanceCreateFlags
Include portability subset devices when enumerating physical devices.
If you enable this flag, you must ensure that your program is prepared to handle the non-conformant aspects of these devices.
If this flag is not enabled, and there are no fully-conformant devices on the system, then
Instance::new will return an IncompatibleDriver error.
The default value is false.
Notes
If this flag is enabled, and the khr_portability_enumeration extension is supported,
it will be enabled automatically when creating the instance.
If the extension is not supported, this flag will be ignored.
Sourcepub const fn empty() -> InstanceCreateFlags
pub const fn empty() -> InstanceCreateFlags
Returns a InstanceCreateFlags with none of the flags set.
Sourcepub const fn none() -> InstanceCreateFlags
👎Deprecated since 0.31.0: use empty instead
pub const fn none() -> InstanceCreateFlags
empty insteadReturns a InstanceCreateFlags with none of the flags set.
Sourcepub const fn intersects(self, other: InstanceCreateFlags) -> bool
pub const fn intersects(self, other: InstanceCreateFlags) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: InstanceCreateFlags) -> bool
pub const fn contains(self, other: InstanceCreateFlags) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn union(self, other: InstanceCreateFlags) -> InstanceCreateFlags
pub const fn union(self, other: InstanceCreateFlags) -> InstanceCreateFlags
Returns the union of self and other.
Sourcepub const fn intersection(
self,
other: InstanceCreateFlags,
) -> InstanceCreateFlags
pub const fn intersection( self, other: InstanceCreateFlags, ) -> InstanceCreateFlags
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: InstanceCreateFlags) -> InstanceCreateFlags
pub const fn difference(self, other: InstanceCreateFlags) -> InstanceCreateFlags
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(
self,
other: InstanceCreateFlags,
) -> InstanceCreateFlags
pub const fn symmetric_difference( self, other: InstanceCreateFlags, ) -> InstanceCreateFlags
Returns the flags that are set in self or other, but not in both.