pub struct DynamicLibraryLoader { /* private fields */ }Expand description
Implementation of Loader that loads Vulkan from a dynamic library.
Implementations
Sourceimpl DynamicLibraryLoader
impl DynamicLibraryLoader
Sourcepub unsafe fn new(
path: impl AsRef<Path>,
) -> Result<DynamicLibraryLoader, LoadingError>
pub unsafe fn new( path: impl AsRef<Path>, ) -> Result<DynamicLibraryLoader, LoadingError>
Tries to load the dynamic library at the given path, and tries to
load vkGetInstanceProcAddr in it.
Safety
- The dynamic library must be a valid Vulkan implementation.