pub enum MemoryAllocatePreference {
Unknown,
NeverAllocate,
AlwaysAllocate,
}Expand description
Describes whether allocating DeviceMemory is desired.
Variants
Unknown
There is no known preference, let the allocator decide.
NeverAllocate
The allocator should never allocate DeviceMemory and should instead only suballocate from
existing blocks.
This option is best suited if you can not afford the overhead of allocating DeviceMemory.
AlwaysAllocate
The allocator should always allocate DeviceMemory.
This option is best suited if you are allocating a long-lived resource that you know could benefit from having a dedicated allocation.