SuballocatorError

Enum SuballocatorError 

pub enum SuballocatorError {
    OutOfRegionMemory,
    FragmentedRegion,
}
Error that can be returned when creating an allocation using a suballocator.

Variants



OutOfRegionMemory

There is no more space available in the region.



FragmentedRegion

The region has enough free space to satisfy the request but is too fragmented.