Suballocation

Struct Suballocation 

pub struct Suballocation {
    pub offset: u64,
    pub size: u64,
    pub allocation_type: AllocationType,
    pub handle: AllocationHandle,
}
An allocation made using a suballocator.

Fields

offset: u64

The absolute offset within the region. That means that this is already offset by the region’s offset, not relative to beginning of the region. This offset will be aligned to the requested alignment.

size: u64

The size of the allocation. This will be exactly equal to the requested size.

allocation_type: AllocationType

The type of resources that can be bound to this memory block. This will be exactly equal to the requested allocation type.

handle: AllocationHandle

An opaque handle identifying the allocation within the allocator.