ExternalMemoryHandleTypes

Struct ExternalMemoryHandleTypes 

pub struct ExternalMemoryHandleTypes(/* private fields */);
A set of ExternalMemoryHandleType values.

Implementations

Source

impl ExternalMemoryHandleTypes

pub const OPAQUE_FD: ExternalMemoryHandleTypes

A POSIX file descriptor handle that is only usable with Vulkan and compatible APIs.

pub const OPAQUE_WIN32: ExternalMemoryHandleTypes

A Windows NT handle that is only usable with Vulkan and compatible APIs.

pub const OPAQUE_WIN32_KMT: ExternalMemoryHandleTypes

A Windows global share handle that is only usable with Vulkan and compatible APIs.

pub const D3D11_TEXTURE: ExternalMemoryHandleTypes

A Windows NT handle that refers to a Direct3D 10 or 11 texture resource.

pub const D3D11_TEXTURE_KMT: ExternalMemoryHandleTypes

A Windows global share handle that refers to a Direct3D 10 or 11 texture resource.

pub const D3D12_HEAP: ExternalMemoryHandleTypes

A Windows NT handle that refers to a Direct3D 12 heap resource.

pub const D3D12_RESOURCE: ExternalMemoryHandleTypes

A Windows NT handle that refers to a Direct3D 12 committed resource.

pub const DMA_BUF: ExternalMemoryHandleTypes

A POSIX file descriptor handle that refers to a Linux dma-buf.

pub const ANDROID_HARDWARE_BUFFER: ExternalMemoryHandleTypes

A handle for an Android AHardwareBuffer object.

pub const HOST_ALLOCATION: ExternalMemoryHandleTypes

A pointer to memory that was allocated by the host.

pub const HOST_MAPPED_FOREIGN_MEMORY: ExternalMemoryHandleTypes

A pointer to a memory mapping on the host that maps non-host memory.

pub const ZIRCON_VMO: ExternalMemoryHandleTypes

A Zircon handle to a virtual memory object.

pub const RDMA_ADDRESS: ExternalMemoryHandleTypes

A Remote Direct Memory Address handle to an allocation that is accessible by remote devices.

pub const fn empty() -> ExternalMemoryHandleTypes

Returns a ExternalMemoryHandleTypes with none of the flags set.

pub const fn none() -> ExternalMemoryHandleTypes

👎Deprecated since 0.31.0: use empty instead

Returns a ExternalMemoryHandleTypes with none of the flags set.

pub const fn count(self) -> u32

Returns the number of flags set in self.

pub const fn is_empty(self) -> bool

Returns whether no flags are set in self.

pub const fn intersects(self, other: ExternalMemoryHandleTypes) -> bool

Returns whether any flags are set in both self and other.

pub const fn contains(self, other: ExternalMemoryHandleTypes) -> bool

Returns whether all flags in other are set in self.

pub const fn union( self, other: ExternalMemoryHandleTypes, ) -> ExternalMemoryHandleTypes

Returns the union of self and other.

pub const fn intersection( self, other: ExternalMemoryHandleTypes, ) -> ExternalMemoryHandleTypes

Returns the intersection of self and other.

pub const fn difference( self, other: ExternalMemoryHandleTypes, ) -> ExternalMemoryHandleTypes

Returns self without the flags set in other.

pub const fn symmetric_difference( self, other: ExternalMemoryHandleTypes, ) -> ExternalMemoryHandleTypes

Returns the flags that are set in self or other, but not in both.

pub fn contains_enum(self, val: ExternalMemoryHandleType) -> bool

Returns whether self contains the flag corresponding to val.