pub struct SparseImageMemoryBind {
pub aspects: ImageAspects,
pub mip_level: u32,
pub array_layer: u32,
pub offset: [u32; 3],
pub extent: [u32; 3],
pub memory: Option<(Arc<DeviceMemory>, u64)>,
}Expand description
Parameters for a single sparse bind operation on parts of an image with a known memory layout.
This type of sparse bind can only be used for images that have the sparse_residency flag set.
Only the normal texel regions can be bound this way, not the mip tail regions or metadata
aspect.
Fields
aspects: ImageAspectsThe aspects of the image where memory is to be (un)bound.
The default value is ImageAspects::empty(), which must be overridden.
mip_level: u32The mip level of the image where memory is to be (un)bound.
The default value is 0.
array_layer: u32The array layer of the image where memory is to be (un)bound.
The default value is 0.
offset: [u32; 3]The offset in texels (or for compressed images, texel blocks) from the origin of the image, where memory is to be (un)bound.
This must be a multiple of the
SparseImageFormatProperties::image_granularity
value of the image.
The default value is [0; 3].
extent: [u32; 3]The extent in texels (or for compressed images, texel blocks) of the image where memory is to be (un)bound.
This must be a multiple of the
SparseImageFormatProperties::image_granularity
value of the image, or offset + extent for that dimension must equal the image’s total
extent.
The default value is [0; 3], which must be overridden.
memory: Option<(Arc<DeviceMemory>, u64)>If Some, specifies the memory and an offset into that memory that is to be bound.
The provided memory must match the image’s memory requirements.
If None, specifies that existing memory at the specified location is to be unbound.
The default value is None.