pub struct QueryControlFlags(/* private fields */);Expand description
Flags that control how a query is to be executed.
Implementations
Sourceimpl QueryControlFlags
impl QueryControlFlags
Sourcepub const PRECISE: QueryControlFlags
pub const PRECISE: QueryControlFlags
For occlusion queries, specifies that the result must reflect the exact number of tests passed. If not enabled, the query may return a result of 1 even if more fragments passed the test.
Sourcepub const fn empty() -> QueryControlFlags
pub const fn empty() -> QueryControlFlags
Returns a QueryControlFlags with none of the flags set.
Sourcepub const fn none() -> QueryControlFlags
👎Deprecated since 0.31.0: use empty instead
pub const fn none() -> QueryControlFlags
empty insteadReturns a QueryControlFlags with none of the flags set.
Sourcepub const fn intersects(self, other: QueryControlFlags) -> bool
pub const fn intersects(self, other: QueryControlFlags) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: QueryControlFlags) -> bool
pub const fn contains(self, other: QueryControlFlags) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn union(self, other: QueryControlFlags) -> QueryControlFlags
pub const fn union(self, other: QueryControlFlags) -> QueryControlFlags
Returns the union of self and other.
Sourcepub const fn intersection(self, other: QueryControlFlags) -> QueryControlFlags
pub const fn intersection(self, other: QueryControlFlags) -> QueryControlFlags
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: QueryControlFlags) -> QueryControlFlags
pub const fn difference(self, other: QueryControlFlags) -> QueryControlFlags
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(
self,
other: QueryControlFlags,
) -> QueryControlFlags
pub const fn symmetric_difference( self, other: QueryControlFlags, ) -> QueryControlFlags
Returns the flags that are set in self or other, but not in both.