pub struct QueryResultFlags(/* private fields */);Expand description
Flags to control how the results of a query should be retrieved.
VK_QUERY_RESULT_64_BIT is not included, as it is determined automatically via the
QueryResultElement trait.
Implementations
Sourceimpl QueryResultFlags
impl QueryResultFlags
Sourcepub const WAIT: QueryResultFlags
pub const WAIT: QueryResultFlags
Wait for the results to become available before writing the results.
Sourcepub const WITH_AVAILABILITY: QueryResultFlags
pub const WITH_AVAILABILITY: QueryResultFlags
Write an additional element to the end of each query’s results, indicating the availability of the results:
- Nonzero: The results are available, and have been written to the element(s) preceding.
- Zero: The results are not yet available, and have not been written.
Sourcepub const PARTIAL: QueryResultFlags
pub const PARTIAL: QueryResultFlags
Allow writing partial results to the buffer, instead of waiting until they are fully available.
Sourcepub const fn empty() -> QueryResultFlags
pub const fn empty() -> QueryResultFlags
Returns a QueryResultFlags with none of the flags set.
Sourcepub const fn none() -> QueryResultFlags
👎Deprecated since 0.31.0: use empty instead
pub const fn none() -> QueryResultFlags
empty insteadReturns a QueryResultFlags with none of the flags set.
Sourcepub const fn intersects(self, other: QueryResultFlags) -> bool
pub const fn intersects(self, other: QueryResultFlags) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: QueryResultFlags) -> bool
pub const fn contains(self, other: QueryResultFlags) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn union(self, other: QueryResultFlags) -> QueryResultFlags
pub const fn union(self, other: QueryResultFlags) -> QueryResultFlags
Returns the union of self and other.
Sourcepub const fn intersection(self, other: QueryResultFlags) -> QueryResultFlags
pub const fn intersection(self, other: QueryResultFlags) -> QueryResultFlags
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: QueryResultFlags) -> QueryResultFlags
pub const fn difference(self, other: QueryResultFlags) -> QueryResultFlags
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(
self,
other: QueryResultFlags,
) -> QueryResultFlags
pub const fn symmetric_difference( self, other: QueryResultFlags, ) -> QueryResultFlags
Returns the flags that are set in self or other, but not in both.