Framebuffer

Struct Framebuffer 

pub struct Framebuffer { /* private fields */ }
The image views that are attached to a render pass during drawing.

A framebuffer is a collection of images, and supplies the actual inputs and outputs of each attachment within a render pass. Each attachment point in the render pass must have a matching image in the framebuffer.

use vulkano::render_pass::{Framebuffer, FramebufferCreateInfo};

// let render_pass: Arc<_> = ...;
let framebuffer = Framebuffer::new(
    render_pass.clone(),
    FramebufferCreateInfo {
        attachments: vec![view],
        ..Default::default()
    },
)
.unwrap();

Implementations

Source

impl Framebuffer

pub fn new( render_pass: Arc<RenderPass>, create_info: FramebufferCreateInfo, ) -> Result<Arc<Framebuffer>, Validated<VulkanError>>

Creates a new Framebuffer.

pub unsafe fn from_handle( render_pass: Arc<RenderPass>, handle: Framebuffer, create_info: FramebufferCreateInfo, ) -> Arc<Framebuffer>

Creates a new Framebuffer from a raw object handle.

Safety
  • handle must be a valid Vulkan object handle created from render_pass.
  • create_info must match the info used to create the object.
pub fn render_pass(&self) -> &Arc<RenderPass>

Returns the renderpass that was used to create this framebuffer.

pub fn flags(&self) -> FramebufferCreateFlags

Returns the flags that the framebuffer was created with.

pub fn attachments(&self) -> &[Arc<ImageView>]

Returns the attachments of the framebuffer.

pub fn extent(&self) -> [u32; 2]

Returns the extent (width and height) of the framebuffer.

pub fn layers(&self) -> u32

Returns the number of layers of the framebuffer.

pub fn attached_layers_ranges(&self) -> SmallVec<[Range<u32>; 4]>

Returns the layer ranges for all attachments.