pub struct SubbufferAllocatorCreateInfo {
pub arena_size: u64,
pub buffer_usage: BufferUsage,
pub memory_type_filter: MemoryTypeFilter,
pub _ne: NonExhaustive,
}Expand description
Parameters to create a new SubbufferAllocator.
Fields
arena_size: u64Initial size of an arena in bytes.
Ideally this should fit all the data you need to update per frame. So for example, if you need to allocate buffers of size 1K, 2K and 5K each frame, then this should be 8K. If your data is dynamically-sized then try to make an educated guess or simply leave the default.
The default value is 0.
buffer_usage: BufferUsageThe buffer usage that all allocated buffers should have.
The default value is empty, which must be overridden.
memory_type_filter: MemoryTypeFilterThe memory type filter all buffers should be allocated with.
The default value is MemoryTypeFilter::PREFER_DEVICE.
_ne: NonExhaustiveTrait Implementations
Sourceimpl Default for SubbufferAllocatorCreateInfo
impl Default for SubbufferAllocatorCreateInfo
Sourcefn default() -> SubbufferAllocatorCreateInfo
fn default() -> SubbufferAllocatorCreateInfo
Returns the “default value” for a type. Read more