pub struct StandardCommandBufferAllocatorCreateInfo {
pub primary_buffer_count: usize,
pub secondary_buffer_count: usize,
pub _ne: NonExhaustive,
}Expand description
Parameters to create a new StandardCommandBufferAllocator.
Fields
primary_buffer_count: usizeHow many primary command buffers should be allocated per pool.
Each time a thread allocates using some queue family index, and either no pools were initialized yet or all pools are full, a new pool is created for that thread and queue family combination. This option tells the allocator how many primary command buffers should be allocated for that pool. It always allocates exactly this many command buffers at once for the pool, as that is more performant than allocating them one-by-one. What this means is that you should make sure that this is not too large, so that you don’t end up wasting too much memory. You also don’t want this to be too low, because that on the other hand would mean that the pool would have to be reset more often, or that more pools would need to be created, depending on the lifetime of the command buffers.
The default value is 32.
secondary_buffer_count: usizeSame as primary_buffer_count except for secondary command buffers.
The default value is 0.
_ne: NonExhaustiveTrait Implementations
Sourceimpl Clone for StandardCommandBufferAllocatorCreateInfo
impl Clone for StandardCommandBufferAllocatorCreateInfo
Sourcefn clone(&self) -> StandardCommandBufferAllocatorCreateInfo
fn clone(&self) -> StandardCommandBufferAllocatorCreateInfo
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for StandardCommandBufferAllocatorCreateInfo
impl Default for StandardCommandBufferAllocatorCreateInfo
Sourcefn default() -> StandardCommandBufferAllocatorCreateInfo
fn default() -> StandardCommandBufferAllocatorCreateInfo
Sourceimpl PartialEq for StandardCommandBufferAllocatorCreateInfo
impl PartialEq for StandardCommandBufferAllocatorCreateInfo
Sourcefn eq(&self, other: &StandardCommandBufferAllocatorCreateInfo) -> bool
fn eq(&self, other: &StandardCommandBufferAllocatorCreateInfo) -> bool
self and other values to be equal, and is used by ==.