pub unsafe trait CommandBufferAlloc:
DeviceOwned
+ Send
+ Sync
+ 'static {
// Required methods
fn inner(&self) -> &CommandPoolAlloc;
fn queue_family_index(&self) -> u32;
}Expand description
A command buffer allocated from a pool that has finished being recorded.
Safety
See CommandBufferAllocator for information about safety.
Required Methods
Sourcefn inner(&self) -> &CommandPoolAlloc
fn inner(&self) -> &CommandPoolAlloc
Returns the internal object that contains the command buffer.
Sourcefn queue_family_index(&self) -> u32
fn queue_family_index(&self) -> u32
Returns the index of the queue family that the pool targets.