pub unsafe trait SecondaryCommandBufferAbstract:
VulkanObject<Handle = CommandBuffer>
+ DeviceOwned
+ Send
+ Sync {
// Required methods
fn usage(&self) -> CommandBufferUsage;
fn inheritance_info(&self) -> &CommandBufferInheritanceInfo;
fn lock_record(&self) -> Result<(), Box<ValidationError>>;
unsafe fn unlock(&self);
}Required Methods
Sourcefn usage(&self) -> CommandBufferUsage
fn usage(&self) -> CommandBufferUsage
Returns the usage of this command buffer.
Sourcefn inheritance_info(&self) -> &CommandBufferInheritanceInfo
fn inheritance_info(&self) -> &CommandBufferInheritanceInfo
Returns a CommandBufferInheritance value describing the properties that the command
buffer inherits from its parent primary command buffer.
Sourcefn lock_record(&self) -> Result<(), Box<ValidationError>>
fn lock_record(&self) -> Result<(), Box<ValidationError>>
Checks whether this command buffer is allowed to be recorded to a command buffer, and if so locks it.
If you call this function, then you should call unlock afterwards.