DescriptorSetLayoutCreateFlags

Struct DescriptorSetLayoutCreateFlags 

pub struct DescriptorSetLayoutCreateFlags(/* private fields */);
Flags that control how a descriptor set layout is created.

Implementations

Source

impl DescriptorSetLayoutCreateFlags

pub const UPDATE_AFTER_BIND_POOL: DescriptorSetLayoutCreateFlags

Whether descriptor sets using this descriptor set layout must be allocated from a descriptor pool whose flags contain DescriptorPoolCreateFlags::UPDATE_AFTER_BIND. Descriptor set layouts with this flag use alternative (typically higher) device limits on per-stage and total descriptor counts, which have _update_after_bind_ in their names.

This flag must be specified whenever the layout contains one or more bindings that have the DescriptorBindingFlags::UPDATE_AFTER_BIND flag, but can be specified also if none of the bindings have this flag, purely to use the alternative device limits.

pub const PUSH_DESCRIPTOR: DescriptorSetLayoutCreateFlags

Whether the descriptor set layout should be created for push descriptors.

If set, the layout can only be used for push descriptors, and if not set, it can only be used for regular descriptor sets.

If set, there are several restrictions:

pub const fn empty() -> DescriptorSetLayoutCreateFlags

Returns a DescriptorSetLayoutCreateFlags with none of the flags set.

pub const fn none() -> DescriptorSetLayoutCreateFlags

👎Deprecated since 0.31.0: use empty instead

Returns a DescriptorSetLayoutCreateFlags with none of the flags set.

pub const fn count(self) -> u32

Returns the number of flags set in self.

pub const fn is_empty(self) -> bool

Returns whether no flags are set in self.

pub const fn intersects(self, other: DescriptorSetLayoutCreateFlags) -> bool

Returns whether any flags are set in both self and other.

pub const fn contains(self, other: DescriptorSetLayoutCreateFlags) -> bool

Returns whether all flags in other are set in self.

pub const fn union( self, other: DescriptorSetLayoutCreateFlags, ) -> DescriptorSetLayoutCreateFlags

Returns the union of self and other.

pub const fn intersection( self, other: DescriptorSetLayoutCreateFlags, ) -> DescriptorSetLayoutCreateFlags

Returns the intersection of self and other.

pub const fn difference( self, other: DescriptorSetLayoutCreateFlags, ) -> DescriptorSetLayoutCreateFlags

Returns self without the flags set in other.

pub const fn symmetric_difference( self, other: DescriptorSetLayoutCreateFlags, ) -> DescriptorSetLayoutCreateFlags

Returns the flags that are set in self or other, but not in both.