pub struct PersistentDescriptorSet<P = StandardDescriptorSetAlloc> { /* private fields */ }Expand description
A simple, immutable descriptor set that is expected to be long-lived.
Implementations
Sourceimpl PersistentDescriptorSet
impl PersistentDescriptorSet
Sourcepub fn new<A>(
allocator: &A,
layout: Arc<DescriptorSetLayout>,
descriptor_writes: impl IntoIterator<Item = WriteDescriptorSet>,
descriptor_copies: impl IntoIterator<Item = CopyDescriptorSet>,
) -> Result<Arc<PersistentDescriptorSet<<A as DescriptorSetAllocator>::Alloc>>, Validated<VulkanError>>where
A: DescriptorSetAllocator + ?Sized,
pub fn new<A>(
allocator: &A,
layout: Arc<DescriptorSetLayout>,
descriptor_writes: impl IntoIterator<Item = WriteDescriptorSet>,
descriptor_copies: impl IntoIterator<Item = CopyDescriptorSet>,
) -> Result<Arc<PersistentDescriptorSet<<A as DescriptorSetAllocator>::Alloc>>, Validated<VulkanError>>where
A: DescriptorSetAllocator + ?Sized,
Creates and returns a new descriptor set with a variable descriptor count of 0.
See new_with_pool for more.
Sourcepub fn new_variable<A>(
allocator: &A,
layout: Arc<DescriptorSetLayout>,
variable_descriptor_count: u32,
descriptor_writes: impl IntoIterator<Item = WriteDescriptorSet>,
descriptor_copies: impl IntoIterator<Item = CopyDescriptorSet>,
) -> Result<Arc<PersistentDescriptorSet<<A as DescriptorSetAllocator>::Alloc>>, Validated<VulkanError>>where
A: DescriptorSetAllocator + ?Sized,
pub fn new_variable<A>(
allocator: &A,
layout: Arc<DescriptorSetLayout>,
variable_descriptor_count: u32,
descriptor_writes: impl IntoIterator<Item = WriteDescriptorSet>,
descriptor_copies: impl IntoIterator<Item = CopyDescriptorSet>,
) -> Result<Arc<PersistentDescriptorSet<<A as DescriptorSetAllocator>::Alloc>>, Validated<VulkanError>>where
A: DescriptorSetAllocator + ?Sized,
Creates and returns a new descriptor set with the requested variable descriptor count, allocating it from the provided pool.
Panics
- Panics if
layoutwas created for push descriptors rather than descriptor sets. - Panics if
variable_descriptor_countis too large for the givenlayout.