pub struct FormatFeatures(/* private fields */);Expand description
The features supported by a device for an image or buffer with a particular format.
Implementations
Sourceimpl FormatFeatures
impl FormatFeatures
Sourcepub const SAMPLED_IMAGE: FormatFeatures
pub const SAMPLED_IMAGE: FormatFeatures
Can be used with a sampled image descriptor.
Sourcepub const STORAGE_IMAGE: FormatFeatures
pub const STORAGE_IMAGE: FormatFeatures
Can be used with a storage image descriptor.
Sourcepub const STORAGE_IMAGE_ATOMIC: FormatFeatures
pub const STORAGE_IMAGE_ATOMIC: FormatFeatures
Can be used with a storage image descriptor with atomic operations in a shader.
Sourcepub const STORAGE_READ_WITHOUT_FORMAT: FormatFeatures
pub const STORAGE_READ_WITHOUT_FORMAT: FormatFeatures
Can be used with a storage image descriptor for reading, without specifying a format on the image view.
Sourcepub const STORAGE_WRITE_WITHOUT_FORMAT: FormatFeatures
pub const STORAGE_WRITE_WITHOUT_FORMAT: FormatFeatures
Can be used with a storage image descriptor for writing, without specifying a format on the image view.
Sourcepub const COLOR_ATTACHMENT: FormatFeatures
pub const COLOR_ATTACHMENT: FormatFeatures
Can be used with a color attachment in a framebuffer, or with an input attachment descriptor.
Sourcepub const COLOR_ATTACHMENT_BLEND: FormatFeatures
pub const COLOR_ATTACHMENT_BLEND: FormatFeatures
Can be used with a color attachment in a framebuffer with blending, or with an input attachment descriptor.
Sourcepub const DEPTH_STENCIL_ATTACHMENT: FormatFeatures
pub const DEPTH_STENCIL_ATTACHMENT: FormatFeatures
Can be used with a depth/stencil attachment in a framebuffer, or with an input attachment descriptor.
Sourcepub const FRAGMENT_DENSITY_MAP: FormatFeatures
pub const FRAGMENT_DENSITY_MAP: FormatFeatures
Can be used with a fragment density map attachment in a framebuffer.
Sourcepub const FRAGMENT_SHADING_RATE_ATTACHMENT: FormatFeatures
pub const FRAGMENT_SHADING_RATE_ATTACHMENT: FormatFeatures
Can be used with a fragment shading rate attachment in a framebuffer.
Sourcepub const TRANSFER_SRC: FormatFeatures
pub const TRANSFER_SRC: FormatFeatures
Can be used with the source image in a transfer (copy) operation.
Sourcepub const TRANSFER_DST: FormatFeatures
pub const TRANSFER_DST: FormatFeatures
Can be used with the destination image in a transfer (copy) operation.
Sourcepub const BLIT_SRC: FormatFeatures
pub const BLIT_SRC: FormatFeatures
Can be used with the source image in a blit operation.
Sourcepub const BLIT_DST: FormatFeatures
pub const BLIT_DST: FormatFeatures
Can be used with the destination image in a blit operation.
Sourcepub const SAMPLED_IMAGE_FILTER_LINEAR: FormatFeatures
pub const SAMPLED_IMAGE_FILTER_LINEAR: FormatFeatures
Can be used with samplers or as a blit source, using the
Linear filter.
Sourcepub const SAMPLED_IMAGE_FILTER_CUBIC: FormatFeatures
pub const SAMPLED_IMAGE_FILTER_CUBIC: FormatFeatures
Can be used with samplers or as a blit source, using the
Cubic filter.
Sourcepub const SAMPLED_IMAGE_FILTER_MINMAX: FormatFeatures
pub const SAMPLED_IMAGE_FILTER_MINMAX: FormatFeatures
Sourcepub const MIDPOINT_CHROMA_SAMPLES: FormatFeatures
pub const MIDPOINT_CHROMA_SAMPLES: FormatFeatures
Can be used with sampler YCbCr conversions using a chroma offset of
Midpoint.
Sourcepub const COSITED_CHROMA_SAMPLES: FormatFeatures
pub const COSITED_CHROMA_SAMPLES: FormatFeatures
Can be used with sampler YCbCr conversions using a chroma offset of
CositedEven.
Sourcepub const SAMPLED_IMAGE_YCBCR_CONVERSION_LINEAR_FILTER: FormatFeatures
pub const SAMPLED_IMAGE_YCBCR_CONVERSION_LINEAR_FILTER: FormatFeatures
Can be used with sampler YCbCr conversions using the
Linear chroma filter.
Sourcepub const SAMPLED_IMAGE_YCBCR_CONVERSION_SEPARATE_RECONSTRUCTION_FILTER: FormatFeatures
pub const SAMPLED_IMAGE_YCBCR_CONVERSION_SEPARATE_RECONSTRUCTION_FILTER: FormatFeatures
Can be used with sampler YCbCr conversions whose chroma filter differs from the filters of the base sampler.
Sourcepub const SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT: FormatFeatures
pub const SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT: FormatFeatures
When used with a sampler YCbCr conversion, the implementation will always perform explicit chroma reconstruction.
Sourcepub const SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_FORCEABLE: FormatFeatures
pub const SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_FORCEABLE: FormatFeatures
Can be used with sampler YCbCr conversions with forced explicit reconstruction.
Sourcepub const SAMPLED_IMAGE_DEPTH_COMPARISON: FormatFeatures
pub const SAMPLED_IMAGE_DEPTH_COMPARISON: FormatFeatures
Can be used with samplers using depth comparison.
Sourcepub const VIDEO_DECODE_OUTPUT: FormatFeatures
pub const VIDEO_DECODE_OUTPUT: FormatFeatures
Can be used with the output image of a video decode operation.
Sourcepub const VIDEO_DECODE_DPB: FormatFeatures
pub const VIDEO_DECODE_DPB: FormatFeatures
Can be used with the DPB image of a video decode operation.
Sourcepub const VIDEO_ENCODE_INPUT: FormatFeatures
pub const VIDEO_ENCODE_INPUT: FormatFeatures
Can be used with the input image of a video encode operation.
Sourcepub const VIDEO_ENCODE_DPB: FormatFeatures
pub const VIDEO_ENCODE_DPB: FormatFeatures
Can be used with the DPB image of a video encode operation.
Sourcepub const DISJOINT: FormatFeatures
pub const DISJOINT: FormatFeatures
For multi-planar formats, can be used with images created with the DISJOINT flag.
pub const LINEAR_COLOR_ATTACHMENT: FormatFeatures
pub const WEIGHT_IMAGE: FormatFeatures
pub const WEIGHT_SAMPLED_IMAGE: FormatFeatures
pub const BLOCK_MATCHING: FormatFeatures
pub const BOX_FILTER_SAMPLED: FormatFeatures
pub const OPTICAL_FLOW_IMAGE: FormatFeatures
pub const OPTICAL_FLOW_VECTOR: FormatFeatures
pub const OPTICAL_FLOW_COST: FormatFeatures
Sourcepub const UNIFORM_TEXEL_BUFFER: FormatFeatures
pub const UNIFORM_TEXEL_BUFFER: FormatFeatures
Can be used with a uniform texel buffer descriptor.
Sourcepub const STORAGE_TEXEL_BUFFER: FormatFeatures
pub const STORAGE_TEXEL_BUFFER: FormatFeatures
Can be used with a storage texel buffer descriptor.
Sourcepub const STORAGE_TEXEL_BUFFER_ATOMIC: FormatFeatures
pub const STORAGE_TEXEL_BUFFER_ATOMIC: FormatFeatures
Can be used with a storage texel buffer descriptor with atomic operations in a shader.
Sourcepub const VERTEX_BUFFER: FormatFeatures
pub const VERTEX_BUFFER: FormatFeatures
Can be used as the format of a vertex attribute in the vertex input state of a graphics pipeline.
Sourcepub const ACCELERATION_STRUCTURE_VERTEX_BUFFER: FormatFeatures
pub const ACCELERATION_STRUCTURE_VERTEX_BUFFER: FormatFeatures
Can be used as the vertex format when building an acceleration structure.
Sourcepub const fn empty() -> FormatFeatures
pub const fn empty() -> FormatFeatures
Returns a FormatFeatures with none of the flags set.
Sourcepub const fn none() -> FormatFeatures
👎Deprecated since 0.31.0: use empty instead
pub const fn none() -> FormatFeatures
empty insteadReturns a FormatFeatures with none of the flags set.
Sourcepub const fn intersects(self, other: FormatFeatures) -> bool
pub const fn intersects(self, other: FormatFeatures) -> bool
Returns whether any flags are set in both self and other.
Sourcepub const fn contains(self, other: FormatFeatures) -> bool
pub const fn contains(self, other: FormatFeatures) -> bool
Returns whether all flags in other are set in self.
Sourcepub const fn union(self, other: FormatFeatures) -> FormatFeatures
pub const fn union(self, other: FormatFeatures) -> FormatFeatures
Returns the union of self and other.
Sourcepub const fn intersection(self, other: FormatFeatures) -> FormatFeatures
pub const fn intersection(self, other: FormatFeatures) -> FormatFeatures
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: FormatFeatures) -> FormatFeatures
pub const fn difference(self, other: FormatFeatures) -> FormatFeatures
Returns self without the flags set in other.
Sourcepub const fn symmetric_difference(self, other: FormatFeatures) -> FormatFeatures
pub const fn symmetric_difference(self, other: FormatFeatures) -> FormatFeatures
Returns the flags that are set in self or other, but not in both.