pub struct SparseBufferMemoryBind {
pub offset: u64,
pub size: u64,
pub memory: Option<(Arc<DeviceMemory>, u64)>,
}Expand description
Parameters for a single sparse bind operation on a buffer.
Fields
offset: u64The offset in bytes from the start of the buffer’s memory, where memory is to be (un)bound.
The default value is 0.
size: u64The size in bytes of the memory to be (un)bound.
The default value is 0, which must be overridden.
memory: Option<(Arc<DeviceMemory>, u64)>If Some, specifies the memory and an offset into that memory that is to be bound.
The provided memory must match the buffer’s memory requirements.
If None, specifies that existing memory at the specified location is to be unbound.
The default value is None.